Python helpers
==============

``hosts`` and ``patterns``
--------------------------

.. automodule:: django_hosts.defaults
    :members: patterns, host

``reverse_host`` and ``reverse``
--------------------------------

.. automodule:: django_hosts.resolvers
    :members:

``HostSiteManager`` model manager
---------------------------------

.. automodule:: django_hosts.managers
    :members:
